@@ -17,11 +17,7 @@ def get_calling_module(name=None, top_level_only=True):
             yield m
 
     x = next(
-        (
-            m
-            for m in modules_iter()
-            if m and top_module(m.__name__) != top_module(__name__)
-        ),
+        (m for m in modules_iter() if m and top_module(m.__name__) != top_module(__name__)),
         None,
     )
     return x
